.. _install-devstack:

Installation on DevStack
~~~~~~~~~~~~~~~~~~~~~~~~~

In order to install ec2-api with devstack the following should be added to the local.conf or localrc the following line:

.. code-block:: ini

    enable_plugin ec2-api https://opendev.org/openstack/ec2-api
